// This filter set is based on the filterset database distributed by
// adblockrules.org.
//
// License information for the filterset database is available at
// http://adblockrules.org/wiki.php?Wiki:About

#include "adblockrules.h"

namespace adblockrules {

// Ad rules based on 2010-05-10 ruleset from http://adblockrules.org

const char* kAdRegExpString =
      "(.*\\.eert\\.net"
      "|.*ads\\.internet\\.com"
      "|-banner-"
      "|\\.z5x\\.net"
      "|\\.zxxds\\.net"
      "|/ad\\.asp"
      "|/ad\\.php"
      "|/adimage\\.php"
      "|/adjs\\.php"
      "|/adplace\\.js"
      "|/adview\\.php"
      "|/burst.*ad\\.js"
      "|/phpAd"
      "|101com\\.com"
      "|103092804\\.com"
      "|114\\.com\\.cn"
      "|163\\.com"
      "|198\\.173\\.76\\.253"
      "|207\\.182\\.129\\.178"
      "|213\\.91\\.8\\.214"
      "|216\\.105\\.166\\.67"
      "|216\\.65\\.38\\.226"
      "|64\\.38\\.223\\.41"
      "|910\\.dn\\.se"
      "|a.*\\.isohunt\\.com"
      "|a.*\\.sk-gaming\\.com"
      "|a\\.joystiq\\.com"
      "|a\\.mininova\\.org"
      "|a\\.off-road\\.com"
      "|a\\.softpedia\\.com"
      "|a\\.weblogsinc\\.com"
      "|aa\\.voice2page\\.com"
      "|aakv\\.ee"
      "|abm\\.hothardware\\.com"
      "|ad.*\\.afterdawn\\.net"
      "|ad.*\\.aftonbladet\\.se"
      "|ad.*\\.agentinteractive\\.se"
      "|ad.*\\.bushtorrent\\.com"
      "|ad.*\\.fileshack\\.com"
      "|ad.*\\.finditquick\\.com"
      "|ad.*\\.forbes\\.com"
      "|ad.*\\.globe7\\.com"
      "|ad.*\\.gulasidorna\\.se"
      "|ad.*\\.hornymatches\\.com"
      "|ad.*\\.jubii\\.dk"
      "|ad.*\\.nyheter24\\.se"
      "|ad.*\\.pimpernel\\.com"
      "|ad.*\\.program3\\.com"
      "|ad.*\\.queens\\.com\\.my"
      "|ad.*\\.rambler\\.ru"
      "|ad.*\\.seedpeer\\.com"
      "|ad.*\\.startnow\\.com"
      "|ad.*\\.thepiratebay\\.org"
      "|ad.*\\.timeinc\\.net"
      "|ad.*\\.torrentspy\\.com"
      "|ad.*\\.tucows\\.com"
      "|ad.*\\.worldogl\\.com"
      "|ad.*\\.zdnet\\.com"
      "|ad-flow\\.com"
      "|ad\\.directanetworks\\.com"
      "|ad\\.howstuffworks\\.com"
      "|ad\\.jamba\\.net"
      "|ad\\.qx\\.se"
      "|ad4game\\.com"
      "|adaction\\.se"
      "|adaos-ads\\.net"
      "|adbard\\.net"
      "|adbrite\\.com"
      "|adbureau\\.net"
      "|adcode\\.ws"
      "|addesktop\\.com"
      "|adengage\\.com"
      "|adfair\\.se"
      "|adform\\.net"
      "|adfox\\.ru"
      "|adgardener\\.com"
      "|adimg\\.cnet\\.com"
      "|adimg\\.tv\\.com"
      "|adinterax\\.com"
      "|adition\\.net"
      "|adjuggler\\.com"
      "|adlantis\\.jp"
      "|adlink\\.net"
      "|adlog\\.com\\.com"
      "|admeta\\.com"
      "|admob\\.com"
      "|adms\\.physorg\\.com"
      "|adnet\\.biz"
      "|adnet\\.ru"
      "|adnetinteractive\\.com"
      "|adonion\\.com"
      "|adoperator\\.com"
      "|adperium\\.com"
      "|adprotraffic\\.com"
      "|adquest\\.nl"
      "|adreactor\\.com"
      "|adrenaline\\.cz"
      "|adrevolver\\.com"
      "|adriver\\.ru"
      "|adroll\\.com"
      "|ads.*\\.brazzers\\.com"
      "|ads.*\\.exhedra\\.com"
      "|ads.*\\.facebook\\.com"
      "|ads.*\\.legitreviews\\.com"
      "|ads.*\\.msn\\.com"
      "|ads.*\\.securityfocus\\.com"
      "|ads.*\\.sitepoint\\.com"
      "|ads.*\\.youporn\\.com"
      "|ads\\.breakthru\\.com"
      "|ads\\.cnn\\.com"
      "|ads\\.com\\.com"
      "|ads\\.ft\\.com"
      "|ads\\.guardian\\.co\\.uk"
      "|ads\\.ign\\.com"
      "|ads\\.imgur\\.com"
      "|ads\\.kajgana\\.mk"
      "|ads\\.kajgana\\.net"
      "|ads\\.linuxfoundation\\.org"
      "|ads\\.mobygames\\.com"
      "|ads\\.newgrounds\\.com"
      "|ads\\.opensubtitles\\.org"
      "|ads\\.sixapart\\.com"
      "|ads\\.stackoverflow\\.com"
      "|ads\\.sumotorrent\\.com"
      "|ads\\.telegraph\\.co\\.uk"
      "|ads\\.torrentreactor\\.net"
      "|ads\\.xhamster\\.com"
      "|ads\\.yimg\\.com"
      "|adscale\\.de"
      "|adscendmedia\\.com"
      "|adservenow\\.com"
      "|adserver\\.yahoo\\.com"
      "|adserverplus\\.com"
      "|adservinginternational\\.com"
      "|adsfac\\.us"
      "|adshuffle\\.com"
      "|adsonar\\.com"
      "|adsrevenue\\.net"
      "|adtech\\.de"
      "|adtechus\\.com"
      "|adtegrity\\.net"
      "|adtoll\\.com"
      "|adtology\\.com"
      "|adtology2\\.com"
      "|adtology3\\.com"
      "|adtoma\\.com"
      "|adtomafusion\\.com"
      "|adtrade\\.net"
      "|adtrgt\\.com"
      "|adultfinder\\.com"
      "|adulttrafficgenerator\\.com"
      "|adv\\.blogupp\\.com"
      "|advertisement\\.gif"
      "|advertising\\.com"
      "|advertserve\\.com"
      "|advertstream\\.com"
      "|adviva\\.net"
      "|advpoints\\.com"
      "|adxpower\\.com"
      "|adyea\\.com"
      "|afcyhf\\.com"
      "|affiliate\\.lik-sang\\.com"
      "|affiliatelounge\\.com"
      "|affiliator\\.com"
      "|affinity\\.com"
      "|aftonbladet-cdn\\.se/template/ver1-0/gfx/ads/"
      "|aftonbladet\\.se/template/ver1-0/gfx/ads/"
      "|afy11\\.net"
      "|aim4media\\.com"
      "|all-cheap-hosting\\.com/fl/cheaphost\\.php"
      "|amgdgt\\.com"
      "|anm\\.co\\.uk"
      "|annonsfabriken\\.se"
      "|anonymouse\\.org/ad"
      "|anonymouse\\.org/adbig"
      "|anonymouse\\.org/adbig\\.html"
      "|anrdoezrs\\.net"
      "|as\\.webmd\\.com"
      "|atdmt\\.com"
      "|atemda\\.com"
      "|atwola\\.com"
      "|au2m8\\.com"
      "|autocontext\\.begun\\.ru"
      "|autotrader\\.co\\.uk"
      "|aweber\\.com"
      "|awltovhc\\.com"
      "|axelsfun\\.com"
      "|axf8\\.net"
      "|axill\\.com"
      "|azjmp\\.com"
      "|azoogleads\\.com"
      "|backbeatmedia\\.com"
      "|bandy\\.prisjakt\\.nu"
      "|banner\\.swf"
      "|bannerconnect\\.net"
      "|bannersxchange\\.com"
      "|bans\\.bride\\.ru"
      "|baventures\\.com"
      "|bc\\..*\\.yahoo\\.com"
      "|betapet\\.com/crystone\\.swf"
      "|betarget\\.net"
      "|bidsystem\\.com"
      "|bidvertiser\\.com"
      "|bin-layer\\.de"
      "|biowebb-data\\..*\\.amazonaws\\.com"
      "|bit-tech\\.net/apps/max/"
      "|bizad\\.nikkeibp\\.co\\.jp"
      "|bizrate\\.com"
      "|blogads\\.com"
      "|blogrolling\\.com"
      "|bluestreak\\.com"
      "|bns1\\.net"
      "|boago\\.com"
      "|bodyclick\\.net"
      "|bonnierdigitalservices\\.com"
      "|bootcampmedia\\.com"
      "|brandreachsys\\.com"
      "|brastart\\.com/layer/layer\\.php"
      "|bravenet\\.com/cserv\\.php"
      "|budsinc\\.com"
      "|burstnet\\.com"
      "|buysellads\\.com"
      "|bwp\\.techrepublic\\.com\\.com"
      "|bwp\\.zdnet\\.com"
      "|camazon\\.com"
      "|casalemedia\\.com"
      "|cash4members\\.com"
      "|cbanners\\.virtuagirlhd\\.com"
      "|checkm8\\.com"
      "|chitika\\.net"
      "|cigarettkungen\\.se/affiliate"
      "|cjt1\\.net"
      "|click\\.inn\\.co\\.il"
      "|click4click\\.com"
      "|clickbangpop\\.com"
      "|clickerpicker\\.com"
      "|clickhype\\.com"
      "|clickintext\\.net"
      "|clicksor\\.com"
      "|clicktorrent\\.info"
      "|cltomedia\\.info"
      "|cnn\\.net/.*/fn_ad"
      "|cnn\\.net/cnn/cnn_ad"
      "|cnzz\\.com"
      "|code-server\\.biz"
      "|codeproject\\.com/script/admentor/"
      "|codeproject\\.com/script/ann/"
      "|collective-media\\.net"
      "|comclick\\.com"
      "|commindo-media-ressourcen\\.de"
      "|common\\.allakhazam\\.com/ads/"
      "|confirmit\\.com"
      "|connextra\\.com"
      "|contaxe\\.com"
      "|contextweb\\.com"
      "|coza\\.com"
      "|cpays\\.com"
      "|cpmstar\\.com"
      "|cpro\\.baidu\\.com"
      "|cpxinteractive\\.com"
      "|createreach\\.com"
      "|crowdgravity\\.com"
      "|crwdcntrl\\.net"
      "|customers\\.luna\\.net"
      "|d\\.techcrunch\\.com"
      "|dagbladet\\.no/an/"
      "|datinggold\\.com"
      "|de\\.rottentomatoes\\.com"
      "|de17a\\.com"
      "|dealtime\\.com"
      "|decordot\\.com"
      "|delivery\\.yourfuckbook\\.com"
      "|dev-se\\.spray\\.se"
      "|devx\\.com/jsww/"
      "|dinclinx\\.com"
      "|direct\\.ninemsn\\.com\\.au"
      "|directaclick\\.com"
      "|directorym\\.com"
      "|directtrack\\.com"
      "|displayadsmedia\\.com"
      "|double\\.net"
      "|doubleclick\\.net"
      "|doublepimp\\.com"
      "|dpbolvw\\.net"
      "|dt00\\.net"
      "|dynamic.*\\.anandtech\\.com"
      "|dynamic\\.dailytech\\.com"
      "|dynamitedata\\.com"
      "|e-bannerx\\.com"
      "|e-planning\\.net"
      "|e-referrer\\.com"
      "|eas\\.blocket\\.se"
      "|ebayobjects\\.com"
      "|edo\\.se"
      "|emediate\\.dk"
      "|emediate\\.eu"
      "|emediate\\.se"
      "|eq\\.mapfiend\\.net/bserv\\.php"
      "|eqrankings\\.com/adv"
      "|eroticmoviebox\\.com"
      "|esportad\\.com"
      "|espotting\\.com"
      "|estat\\.com"
      "|estelle\\.tv"
      "|etology\\.com"
      "|euroclick\\.com"
      "|euros4click\\.de"
      "|ex\\.gamecopyworld\\.com"
      "|exaccess\\.ru"
      "|exchange-it\\.com"
      "|expressen\\.se/expressen/jsp/index\\.ajax"
      "|eyewonder\\.com"
      "|fairfax\\.com\\.au"
      "|falkag\\.de"
      "|falkag\\.net"
      "|famoushosting\\.net"
      "|fastclick\\.net"
      "|fe\\.lea\\.spray\\.se"
      "|filetarget\\.com"
      "|fimserve\\.com"
      "|finestresults\\.com"
      "|firstadsolution\\.com"
      "|firstload\\.de"
      "|flashback\\.info/images/annons\\.gif"
      "|flashtalking\\.com"
      "|fling\\.com"
      "|fmpub\\.net"
      "|fortunecity\\.com/js/ad"
      "|free-banners\\.com"
      "|free-rencontre\\.com/slidein"
      "|free-web-space-finder\\.com/images2/floatheader"
      "|free-webhosts\\.com/images/a/"
      "|freecpanels\\.com/live/image\\.php"
      "|friendlyduck\\.com"
      "|ftjcfx\\.com"
      "|fuck-access\\.com"
      "|fusion\\.expressen\\.se"
      "|fwmrm\\.net"
      "|g\\.helgon\\.se/a/"
      "|gadex\\.com"
      "|game-advertising-online\\.com"
      "|gamesbanner\\.net"
      "|gamespaid\\.com/display\\.php"
      "|gavzad\\.keenspot\\.com"
      "|geek-tools\\.org"
      "|gestionpub\\.com"
      "|gfx\\.dagbladet\\.no/g2/ad-v4\\.gif"
      "|globalinteractive\\.com"
      "|gon\\.se/adnet"
      "|gonamic\\.de"
      "|googleadservices\\.com"
      "|googlesyndication\\.com"
      "|groups\\.google\\..*adfetch"
      "|gunggo\\.com"
      "|haket\\.com/images/banners/"
      "|harrenmedianetwork\\.com"
      "|hb\\.lycos\\.com"
      "|helgon\\.se/links/ext_link.*"
      "|helgon\\.se/picz/links\\.gif"
      "|hera\\.hardocp\\.com"
      "|hopfeed\\.com"
      "|hotadv\\.com"
      "|http://.*\\.ipro\\.com"
      "|http://ads\\..*\\.amazonaws\\.com"
      "|http://banner.*\\."
      "|http://www\\.zyzoom\\.org/vb/e3lan/"
      "|httpool\\.com"
      "|https://banner.*\\."
      "|humanclick\\.com"
      "|i\\.rottentomatoes\\.com"
      "|i12\\.de"
      "|icq\\.com/.*google_ad\\.js"
      "|icq\\.com/img/index/template/ad\\.gif"
      "|identads\\.com"
      "|iframe\\.adultfriendfinder\\.com"
      "|imagebanana\\.com"
      "|images\\.ifriends\\.net/affiliate_programs"
      "|images\\.thetimes\\.co\\.uk/TGD/picture/0,,89474,00\\.gif"
      "|imdb\\.com/google"
      "|img\\.shopping\\.com"
      "|imho\\.ru"
      "|impact-ad\\.jp"
      "|impresionesweb\\.com"
      "|indieclick\\.com"
      "|industrybrains\\.com"
      "|infinisource\\.com/cgi-bin/Count"
      "|infolinks\\.com"
      "|insightexpressai\\.com"
      "|instream\\.com"
      "|interclick\\.com"
      "|isoftmarketing\\.com"
      "|isohunt\\.com/a/"
      "|isohunt\\.com/js/iframeAd\\.php"
      "|jdoqocy\\.com"
      "|jiggieads\\.com/"
      "|jobbexpressen\\.se/tv3\\.php"
      "|jubii\\.dk/.*/ad"
      "|juiceadv\\.com"
      "|juicyads\\.com"
      "|jumpdisplay\\.com"
      "|just-hitz\\.org"
      "|justrelevant\\.com"
      "|kaboose\\.com/images/ad"
      "|kaboose\\.com/javascript/ad"
      "|kanoodle\\.com"
      "|kerg\\.net"
      "|keymedia\\.ru"
      "|kidsdomain\\.com.*/adcode\\.js"
      "|kinetc\\.com"
      "|klikki\\.com"
      "|komli\\.com"
      "|komplett\\.se/mlf/produkt/bilder/ukens"
      "|kontera\\.com"
      "|kqzyfj\\.com"
      "|lakequincy\\.com"
      "|last\\.fm/adserver"
      "|last\\.fm/show_ads"
      "|layer-ads\\.de"
      "|lbn\\.ru"
      "|lduhtrp\\.net"
      "|lijit\\.com"
      "|lingospot\\.com"
      "|linkexchange\\.com"
      "|linkstorms\\.com"
      "|linksynergy\\.com"
      "|linuxnewmedia\\.com"
      "|lnkworld\\.com"
      "|loading321\\.com"
      "|lunafetch\\.about\\.com"
      "|lunamedia\\.com\\.au"
      "|lunarstorm\\.se/.*/pp_banner"
      "|lw\\.cdmediaworld\\.com"
      "|mads\\.cnet\\.com"
      "|mads\\.com\\.com"
      "|mads\\.gamefaqs\\.com"
      "|magiclayer\\.com"
      "|marketing\\.888\\.com"
      "|maxserving\\.com"
      "|media-servers\\.net"
      "|media6degrees\\.com"
      "|mediagridwork\\.com"
      "|mediamgr\\.ugo\\.com"
      "|mediaplazza\\.com"
      "|mediaplex\\.com"
      "|mediashakers\\.com"
      "|medleyads\\.com"
      "|megaclick\\.com"
      "|metro\\.se/.*/ad"
      "|mikkelsenmedia\\.dk"
      "|mmismm\\.com"
      "|mmmedier\\.se"
      "|mochila\\.com"
      "|modmyads\\.com"
      "|mootermedia\\.com"
      "|motigo\\.com/ads"
      "|mpmcash\\.com"
      "|msads\\.net"
      "|myaffiliateprogram\\.com"
      "|mydeluxegames\\.com"
      "|mydirtyhobby\\.com"
      "|naonmedia\\.net"
      "|netavenir\\.com"
      "|netshelter\\.net"
      "|network\\.business\\.com"
      "|network\\.kaboose\\.com"
      "|network\\.realmedia\\.com"
      "|newgrounds\\.com/iframe_comotion2\\.html"
      "|newgrounds\\.com/iframe_rightmedia\\.html"
      "|news\\.zdnet\\.co\\.uk/.*/ad-str-148-up\\.gif"
      "|ngads\\.com/getad\\.php"
      "|ngs\\.impress\\.co\\.jp"
      "|northmay\\.com"
      "|np-media\\.de"
      "|nyadmcncserve-05y06a\\.com"
      "|oas\\.dagensmedia\\.se"
      "|oas\\.dn\\.se"
      "|oas\\.unt\\.se"
      "|oascentral\\.citypages\\.com"
      "|offermatica\\.com"
      "|ojdinteractiva\\.com"
      "|openads\\.xornet\\.net"
      "|openx\\.linuxforums\\.org"
      "|openx\\.org"
      "|panthercustomer\\.com"
      "|passwordbyphone\\.com"
      "|paypopup\\.com"
      "|pcmag\\.com/images/pcm.*_ad"
      "|peer39\\.net"
      "|pgmediaserve\\.com"
      "|pheedo\\.com"
      "|picadmedia\\.com"
      "|platsnatet\\.se"
      "|plyrics\\.com/bbanlyr\\.js"
      "|plyrics\\.com/head\\.js"
      "|plyrics\\.com/tbanlyr\\.js"
      "|pointroll\\.com"
      "|pool\\.dt\\.se"
      "|pop6\\.com"
      "|pops\\.freeze\\.com"
      "|popunder\\.ru"
      "|precisionclick\\.com"
      "|predictad\\.com"
      "|predictad\\.net"
      "|prisjakt\\.nu/ajax/openx_ajs_proxy"
      "|pro-market\\.net"
      "|projectwonderful\\.com"
      "|promo-reklama\\.ru"
      "|promobenef\\.com"
      "|promos\\.fling\\.com"
      "|publicidad\\.net"
      "|qksrv\\.net"
      "|qksz\\.net"
      "|quartermedia\\.de"
      "|quarterserver\\.de"
      "|rad\\.msn\\.com"
      "|reachjunction\\.com"
      "|reactivpub\\.fr"
      "|realcastmedia\\.com"
      "|realclick\\.co\\.kr"
      "|reduxmedia\\.com"
      "|rek\\.snyggast\\.se"
      "|reklampoolen\\.com"
      "|revenue\\.net"
      "|revfusion\\.net"
      "|rmxads\\.com"
      "|rubiconproject\\.com"
      "|scanmedios\\.com"
      "|scripts\\.lycos\\.com"
      "|sexlist\\.com"
      "|shareasale\\.com"
      "|shockwave\\.com/js/ad\\.js"
      "|shorttail\\.net"
      "|skunk\\.spray\\.se/scripts/survey\\.js"
      "|smartadserver\\.com"
      "|smarttargetting\\.net"
      "|smowtion\\.com"
      "|smrtlnks\\.com"
      "|socialreach\\.com"
      "|sonnerie\\.net"
      "|specificmedia\\.co\\.uk"
      "|spot200\\.com"
      "|statcamp\\.net"
      "|static\\.flashback\\.info/img/b/"
      "|static\\.tv4\\.se/swf/tv4/Ad"
      "|streamray\\.com"
      "|svd\\.se/images/sys/admark"
      "|tacoda\\.net"
      "|tahono\\.com"
      "|tailsweep\\.com"
      "|targetpoint\\.com"
      "|technoratimedia\\.com"
      "|thecanadianteacher\\.com/ad"
      "|thedailywtf\\.com/tizes/"
      "|thewheelof\\.com"
      "|tidningsnatet\\.se"
      "|timeinc\\.net/subs/popup"
      "|tiser\\.com\\.au"
      "|tkqlhce\\.com"
      "|tnn\\.co\\.uk"
      "|toplaboom\\.com"
      "|toplist\\.cz"
      "|topsearch10\\.com"
      "|torrentreactor\\.to/bannerunx\\.php"
      "|torrentreactor\\.to/fullreleases\\.htm"
      "|total-media\\.net"
      "|tqlkg\\.com"
      "|tradera\\.com/images/stortavla_top\\.gif"
      "|tradera\\.com/search/google\\.aspx"
      "|trafficjunky\\.net"
      "|tribalfusion\\.com"
      "|tripod\\.com/adm/ad"
      "|ttzmedia\\.com"
      "|tucows\\.com/img/ad"
      "|tucows\\.com/js/google"
      "|tv-serieguiden\\.com/reklam"
      "|txtad\\.se"
      "|u\\.e78\\.com"
      "|u\\.npr\\.org"
      "|ufobucks\\.com"
      "|undertexter\\.se/banner/"
      "|unicast\\.com"
      "|users\\.se"
      "|vadpay\\.com"
      "|valueclick\\.com"
      "|valueclick\\.net"
      "|vibrantmedia\\.com"
      "|videoegg\\.com"
      "|viragemedia\\.com"
      "|viraladnetwork\\.net"
      "|watersoul\\.com"
      "|web-source\\.net/ad"
      "|webflash\\.com"
      "|webgirls-online\\.com"
      "|weborama\\.fr"
      "|webring\\.com"
      "|webserviceaward\\.com"
      "|webtraffic\\.se"
      "|widgeo\\.net"
      "|widgetbucks\\.com"
      "|winfixer\\.com"
      "|wrapper\\.ign\\.com"
      "|wunderloop\\.net"
      "|www\\.ad\\."
      "|xiti\\.com"
      "|xplusone\\.com"
      "|xtendmedia\\.com"
      "|xtreme\\.se"
      "|xxx-hitz\\.org"
      "|yahoo\\.com/get_ad"
      "|yesmessenger\\.com"
      "|yieldmanager\\.com"
      "|yieldmanager\\.edgesuite\\.net"
      "|yieldmanager\\.net"
      "|yimg\\.com/.*/lib/bc"
      "|yournetaccess\\.com"
      "|yumenetworks\\.com"
      "|zedo\\.com"
      "|zeus\\.developershed\\.com"
      "|sifomedia\\..*\\.se)";

}  // namespace adblockrules
