// This filter set is based on the filterset database distributed by
// adblockrules.org.
//
// License information for the filterset database is available at
// http://adblockrules.org/wiki.php?Wiki:About

#include "adblockrules.h"

namespace adblockrules {

// Ad rules based on 2010-05-10 ruleset from http://adblockrules.org

const char* kTrackerRegExpString =
      "(.*\\.bc\\.yahoo\\.com"
      "|.*\\.ts\\.se"
      "|.*\\.yimg\\.com/.*/bcr_.*\\.js"
      "|.*imgcount.*"
      "|\\.stats\\.de"
      "|/adlog\\.php"
      "|/hitbox\\.js"
      "|/ntpagetag\\.js"
      "|/onestat\\.js"
      "|174\\.129\\.110\\.24"
      "|1javastreet\\.com/dm\\.gif"
      "|213\\.115\\.215\\.79"
      "|247realmedia\\.com"
      "|2o7\\.net"
      "|360i\\.com"
      "|51\\.la"
      "|51yes\\.com"
      "|a\\.amd\\.com"
      "|about\\.com/blank\\.gif"
      "|ad\\.zanox\\.com"
      "|adaptlogic\\.com"
      "|adnxs\\.com"
      "|adtraxx\\.de"
      "|advancedsubmitter\\.com"
      "|advista\\.no"
      "|agim\\.co\\.uk"
      "|akkza\\.se"
      "|allakhazam\\.com/.*/wt\\.js"
      "|altus\\.se"
      "|amung\\.us"
      "|analytics\\.live\\.com"
      "|analytics\\.msn\\.com"
      "|analytics\\.yahoo\\.com"
      "|angelfire\\.com/.*track"
      "|apicasystem\\.com"
      "|app2\\.agentinteractive\\.se"
      "|as\\.cmpnet\\.com"
      "|ask\\.com/i/i\\.gif"
      "|assoc-amazon\\.com"
      "|att\\.com/library/behavior"
      "|bdh\\.textalk\\.se"
      "|bfast\\.com"
      "|bigstats\\.net"
      "|biz5\\.ogt\\.jp"
      "|blogtoplist\\.com"
      "|brinkster\\.com/rd\\.asp"
      "|c\\.bigmir\\.net"
      "|c\\.lygo\\.com"
      "|centrport\\.com"
      "|centrport\\.net"
      "|cetrk\\.com"
      "|channelintelligence\\.com"
      "|chartbeat\\.com"
      "|chartbeat\\.net"
      "|cibleclick\\.com"
      "|click\\.dagbladet\\.no/pageviews"
      "|clickability\\.com"
      "|clickdensity\\.com"
      "|clickpathmedia"
      "|clicktracks\\.aristotle\\.net"
      "|clicktracks\\.com"
      "|cneteu\\.net/.*/b\\.gif"
      "|cnn\\.com/cookie"
      "|collarity\\.com"
      "|collect\\.realmedia\\.com"
      "|com\\.com/.*dm_client_CNET\\.js"
      "|coremetrics\\.com"
      "|count\\.rtl\\.de"
      "|counter.*\\.gigya\\.com"
      "|counter\\.internet\\.ge"
      "|counter\\.search\\.bg"
      "|countomat\\.com"
      "|countquest\\.se"
      "|cybermonitor\\.com"
      "|decideinteractive\\.com"
      "|deepmetrix\\.com"
      "|direct-stats\\.com"
      "|dkd\\.lt"
      "|dl-rms\\.com"
      "|dmdelivery\\.com"
      "|dmtracker\\.com"
      "|double\\.se"
      "|dropit\\.se"
      "|dw-eu\\.com\\.com"
      "|earncurve\\.net"
      "|eas\\.hitta\\.se"
      "|easycounter\\.com"
      "|easyresearch\\.se"
      "|econda-monitor\\.de"
      "|eloqua\\.com"
      "|emetrix\\.com"
      "|enecto\\.com"
      "|eniro\\.se/img/sik\\.gif"
      "|enquisite\\.com"
      "|esitestats\\.com"
      "|etracker\\.com"
      "|evisitanalyst\\.com"
      "|exponential\\.com"
      "|extreme-dm\\.com"
      "|fastcounter\\.bcentral\\.com"
      "|fateback\\.com"
      "|fazoon\\.com"
      "|feedjit\\.com"
      "|flash-stat\\.com"
      "|fortunecity\\.com/js/hitslink_tracktraffic\\.js"
      "|free-easy-counters\\.com"
      "|free-webhosts\\.com/stats"
      "|freewebs\\.com/eluminate"
      "|freshmeat\\.net/pc\\.gif"
      "|gemius\\.pl"
      "|getclicky\\.com"
      "|glanceguide\\.com"
      "|goingup\\.com"
      "|gon\\.se/adcount"
      "|gon\\.se/netStats"
      "|google-analytics\\.com"
      "|gostats\\.com"
      "|gtop\\.ro"
      "|hit-parade\\.com"
      "|hitbox\\.com"
      "|hits\\.e\\.cl"
      "|hitslink\\.com"
      "|hittail\\.com"
      "|host-tracker\\.com"
      "|hotlog\\.ru"
      "|http://c\\.microsoft\\.com"
      "|http://c\\.msn\\.com"
      "|i-mining\\.nl"
      "|ibm\\.com/.*/c\\.gif"
      "|iivt\\.com"
      "|imrworldwide\\.com"
      "|indextools\\.com"
      "|instadia"
      "|intelli-direct\\.com"
      "|intellitxt\\.com"
      "|iperceptions\\.com"
      "|iprocollect\\.realmedia\\.com"
      "|jajja\\.com"
      "|johan\\.galaxen\\.net"
      "|jubii\\.dk/jubii\\.dll"
      "|kaboose\\.com/.*/cookie\\.gif"
      "|kmindex\\.ru"
      "|komplett-analytics\\.com"
      "|ld\\.svt\\.se"
      "|lingon\\.nu/skunk"
      "|list\\.ru"
      "|livehit\\.net"
      "|liveperson\\.net"
      "|lloogg\\.com"
      "|loading\\.se/adcount"
      "|log\\.go\\.com"
      "|log\\.releware\\.net"
      "|lypn\\.com"
      "|mail\\.google\\.com/mail/images/c\\.gif"
      "|mc\\.yandex\\.ru"
      "|mediaonenetwork\\.net"
      "|metrics\\.aftonbladet\\.se"
      "|metrics\\.amd\\.com"
      "|metrics\\.expressen\\.se"
      "|minicars\\.se/skunk"
      "|mtrcs\\.redhat\\.com"
      "|mtv\\.com/sitewide/images/spacer\\.gif"
      "|mybloglog\\.com"
      "|mystat\\.hu"
      "|mystats\\.nl"
      "|naiadsystems\\.com"
      "|nedstat\\.net"
      "|nedstatbasic\\.net"
      "|net-filter\\.com"
      "|netdebit-counter\\.de"
      "|nextstep\\.org\\.uk/dm\\.gif"
      "|notabenestats\\.net"
      "|nuggad\\.net"
      "|om\\.symantec\\.com"
      "|omniture\\.stats\\.dn\\.se"
      "|onenetworkdirect\\.net"
      "|onestat\\.com"
      "|onlineservicesas\\.com"
      "|optimost\\.com"
      "|osdn\\.com/pc\\.gif"
      "|overture\\.com"
      "|p\\.reuters\\.com"
      "|pa\\.yahoo\\.com"
      "|pclick\\.internal\\.yahoo\\.com"
      "|performancing\\.com"
      "|pixel\\.quantserve\\.com"
      "|planet-source-code\\.com/dm\\.gif"
      "|pmsrvr\\.com"
      "|proext\\.com"
      "|prospectxtractor\\.se"
      "|purevideo\\.com"
      "|ranking-hits\\.de"
      "|rapidstats\\.de"
      "|redirect\\.alexa\\.com"
      "|reinvigorate\\.net"
      "|rejestr\\.org"
      "|reliablestats\\.com"
      "|res-x\\.com"
      "|research-int\\.se"
      "|revsci\\.net"
      "|roiservice\\.com"
      "|roventskij\\.net/skunk/"
      "|sageanalyst\\.net"
      "|sajtanalys\\.se"
      "|sdc\\.kaboose\\.com"
      "|search\\.com/bw\\.gif"
      "|searchportal\\.information\\.com"
      "|securestudies\\.com"
      "|seowebb\\.se"
      "|serating\\.ru"
      "|sexcounter\\.com"
      "|sextracker\\.com"
      "|sis-index\\.se"
      "|sitemeter\\.com"
      "|sitestat\\.com"
      "|skunk\\.himynameisjonas\\.net"
      "|skunk\\.koigii\\.se"
      "|smack\\.se/netStats"
      "|smartsource\\.wiley\\.com"
      "|smarttargetting\\.com"
      "|snoobi\\.com"
      "|sophus3\\.com"
      "|sparkstudios\\.com"
      "|spisanie\\.com/c/"
      "|spylog\\.com"
      "|srd\\.yahoo\\.com"
      "|stat.*\\.ibm\\.com"
      "|stat\\.pl"
      "|statcounter\\.com"
      "|statistici\\.ro"
      "|statistik-gallup\\.net"
      "|stats\\.agentinteractive\\.com"
      "|stats\\.bbc\\.co\\.uk"
      "|stats\\.big-boards\\.com"
      "|stats\\.fr"
      "|stats\\.liutilities\\.com"
      "|stats\\.macworld\\.com"
      "|stats\\.searchles\\.com"
      "|stats\\.wired\\.com"
      "|stats\\.wordpress\\.com"
      "|support\\.microsoft\\.com/LTS/default"
      "|survey-poll\\.com"
      "|susnet\\.se"
      "|tag\\.brinkster\\.com"
      "|targstat\\.com"
      "|te\\.ap\\.org"
      "|te\\.businessweek\\.com"
      "|te\\.nytimes\\.com"
      "|techbuyer\\.com/images/blank\\.gif"
      "|teljari\\.is"
      "|thottbot\\.com/.*/webtrends\\.js"
      "|tns-counter\\.ru"
      "|top.*\\.mail\\.ru"
      "|top\\.after\\.ge"
      "|top\\.ge"
      "|toplist\\.eu"
      "|toplist\\.sk"
      "|topmango\\.com"
      "|traceworks\\.com"
      "|track.*\\.icons\\.com"
      "|track\\.collegehumor\\.com"
      "|track\\.decideinteractive\\.com"
      "|track\\.effiliation\\.com"
      "|track\\.gawker\\.com"
      "|track\\.mybloglog\\.com"
      "|track\\.topix\\.net"
      "|track\\.x10\\.com"
      "|tracking\\.cafepress\\.com"
      "|tracking\\.foxnews\\.com"
      "|tradedoubler\\.com"
      "|trafficmp\\.com"
      "|trafic\\.ro"
      "|truehits\\.in\\.th"
      "|truehits\\.net"
      "|tucows\\.com/js/cookie"
      "|tv-serieguiden\\.com/.*count\\.asp"
      "|tv-serieguiden\\.com/myasg/stats_js\\.asp"
      "|twittercounter\\.com"
      "|tynt\\.com"
      "|typepad\\.com/t/stats"
      "|uarating\\.com"
      "|umpctopsites\\.com"
      "|unica\\.com"
      "|urchin\\.com"
      "|video\\.od\\.visiblemeasures\\.com"
      "|visit\\.geocities\\.com"
      "|voicefive\\.com"
      "|vs\\.tucows\\.com"
      "|wdcs\\.trendmicro\\.com"
      "|web-stat\\.com"
      "|webcontrol\\.se"
      "|webhosts4free\\.com/stats"
      "|webstat\\.net"
      "|webstat\\.se"
      "|webstats"
      "|webstats4u\\.com"
      "|webtrends\\.com"
      "|webtrends\\.telegraph\\.co\\.uk"
      "|webtrendslive\\.com"
      "|witty\\.se"
      "|woopra\\.com"
      "|ws\\.md"
      "|wt\\.o\\.nytimes\\.com"
      "|xhit\\.com"
      "|xslt\\.alexa\\.com"
      "|xtractor\\.no"
      "|xxxcounter\\.de"
      "|y\\.digg\\.com"
      "|yadro\\.ru"
      "|yimg\\.com/.*/i/mc"
      "|yourtracking\\.net"
      "|zipstat\\.dk"
      "|b\\.scorecardresearch\\.com"
      "|sifomedia\\..*\\.nu)";

}  // namespace adblockrules
